@@ -52,6 +52,9 @@ int CIN_Init()
 	SDL_SysWMinfo wminfo;
 	SDL_VERSION(&wminfo.version);
 
+	/* We need GLib threading working, or GStreamer will quietly do it for us */
+	PDL_EnsureInit();
+
 	if (!basic_init_done) {
 		gst_init(NULL, NULL);
 		basic_init_done = TRUE;
@@ -72,13 +75,47 @@ int CIN_Init()
  * floating around in paused state, I defer creation of it until CIN_Play(). */
 int CIN_LoadCIN(const char *url)
 {
+	GError *err = NULL;
+
+	/* "Unload" previous media. */
+	free_pipeline();
 	g_free(media_uri);
-	if (g_ascii_strncasecmp("file:/", url, 6) == 0) {
-		media_uri = g_strdup(url);
+	media_uri = NULL;
+
+	/* GStreamer wants an absolute URI. Games are sloppy about it. Clean mess. */
+	TRACE("Passed URL=\"%s\"", url);
+	char *path;
+	if (g_ascii_strncasecmp("file://./", url, 8) == 0) {
+		/* Malformed relative file:// uri. */
+		path = realpath(&url[7], NULL);
+	} else if (g_ascii_strncasecmp("file://", url, 6) == 0) {
+		gchar * filename = g_filename_from_uri(url, NULL, &err);
+		if (!filename) {
+			WARN("Failed to parse \"file://\" URI: %s", err->message);
+			return SDL_FALSE;
+		}
+		path = realpath(filename, NULL);
+		g_free(filename);
+	} else if (url[0] == '/') {
+		/* Absolute path */
+		path = strdup(url);
 	} else {
-		media_uri = g_filename_to_uri(url, NULL, NULL);
+		/* Assume it is a relative path. */
+		path = realpath(url, NULL);
 	}
-	TRACE("Will play \"%s\"", media_uri);
+	if (!path) {
+		WARN("Failed to canonicalize path for \"%s\"", url);
+		return SDL_FALSE;
+	}
+
+	media_uri = g_filename_to_uri(path, NULL, &err);
+	free(path);
+
+	if (!media_uri) {
+		WARN("Failed to convert into valid URI: %s", err->message);
+	}
+
+	TRACE("Cleaned URL=\"%s\"", media_uri);
 	return SDL_TRUE;
 }
 
