@@ -3,6 +3,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 
+#include <glib.h>
 #include <SDL.h>
 
 #include "override.h"
@@ -23,7 +24,7 @@ static struct _SDL_Joystick
 } accel = { 0 };
 
 static SDL_bool poll = SDL_TRUE;
-static SDL_TimerID timer = 0;
+static guint timer = 0;
 
 #define SINT16_MAX 32767
 #define SINT16_MIN -32768
@@ -124,10 +125,10 @@ static int accel_update()
 	return 1;
 }
 
-static Uint32 accel_poll(Uint32 interval, void* param)
+static gboolean accel_poll(gpointer data)
 {
-	if (!accel_update()) return 0;
-	return interval;
+	if (!accel_update()) return FALSE;
+	return TRUE;
 }
 
 static void update_polling()
@@ -136,10 +137,10 @@ static void update_polling()
      * get a similar behaviour. */
 	if (accel.opened && poll) {
 		/* Joystick is opened, and we want polling. */
-		timer = SDL_AddTimer(EVENT_INTERVAL, accel_poll, NULL);
+		timer = g_timeout_add(EVENT_INTERVAL, accel_poll, NULL);
 	} else if (timer) {
 		/* Joystick is closed or polling is disabled, kill timer. */
-		SDL_RemoveTimer(timer);
+		g_source_remove(timer);
 		timer = 0;
 	}
 }
@@ -231,7 +232,8 @@ Sint16 SDL_JoystickGetAxis(SDL_Joystick *joystick, int axis)
 		case 2:
 			return accel.z;
 		default:
-			SDL_SetError("Joystick only has 3 axes");
+			WARN("Invalid joystick axis");
+			SDL_SetError("Joystick only has 3 axis");
 			return 0;
 	}
 }
