@@ -45,7 +45,6 @@
 #define UNIQUE_ID_RND_SIZE		24
 
 static gboolean basic_init_done = FALSE;
-static gboolean init_done = FALSE;
 static GMainContext *main_context = NULL;
 static GMainLoop *main_loop = NULL;
 static osso_context_t *osso_context = NULL;
@@ -58,7 +57,6 @@ static LocationGPSDControl *location = NULL;
 static LocationGPSDevice *loc_device = NULL;
 #endif
 
-
 /* Current status */
 static gboolean dimming_prevention_enabled = FALSE;
 static gboolean system_pause_ui_enabled = FALSE;
@@ -249,11 +247,9 @@ PDL_Err PDL_Init(unsigned int flags)
 	}
 
 	/* Check against stupid games calling PDL_Init() twice */
-	if (init_done) {
+	if (osso_context) {
 		WARN("Game called PDL_Init twice");
 		return PDL_NOERROR;
-	} else {
-		init_done = TRUE;
 	}
 
 	/* Get a proper prgname for glib */
@@ -330,7 +326,7 @@ PDL_Err PDL_Init(unsigned int flags)
 
 void PDL_Quit()
 {
-	if (!init_done) {
+	if (!osso_context) {
 		WARN("Game called PDL_Quit without calling PDL_Init first");
 	}
 
@@ -360,8 +356,14 @@ void PDL_Quit()
 	main_context = NULL;
 	g_free(last_error);
 	last_error = NULL;
+}
 
-	init_done = FALSE;
+PDL_Err PDL_EnsureInit()
+{
+	if (!osso_context) {
+		return PDL_Init(0);
+	}
+	return PDL_NOERROR;
 }
 
 /* Stupid games not calling PDL_Init() */
@@ -545,7 +547,7 @@ PDL_Err PDL_GetOSVersion(PDL_OSVersion *version)
 	version->majorVersion = 1;
 	version->minorVersion = 4;
 	version->revision = 5;
-	version->versionStr = "Preenv 0.1.2";
+	version->versionStr = "Preenv 0.1.3";
 	return PDL_NOERROR;
 }
 
