@@ -5,19 +5,14 @@
 #include <SDL_gles.h>
 #include <GLES/gl.h>
 
+#include "SDLGL.h"
+
 #include "override.h"
 #include "private.h"
 #include "debug.h"
 
 #define DEBUG_DOMAIN "SDLGL"
 
-enum {
-	SDL_GL_CONTEXT_MAJOR_VERSION = 17,
-	/* I'm unsure about the below ones: */
-	SDL_GL_CONTEXT_MINOR_VERSION = 19,
-};
-	
-
 static SDL_GLES_Version desired_version = SDL_GLES_VERSION_NONE;
 static SDL_bool gles_inited = SDL_FALSE;
 static SDL_GLES_Context *context = NULL;
